@@ -3,7 +3,7 @@ function(kode=1,ifn,x) {
 if (missing(ifn)) messagena("ifn")
 if (missing(x)) messagena("x")
 p <- single(1)
-f.res <- .Fortran("chisq",
+f.res <- .Fortran("chisqz",
 kode=to.integer(kode),
 ifn=to.integer(ifn),
 x=to.single(x),
