@@ -3,7 +3,7 @@ function(x,p) {
 if (missing(x)) messagena("x")
 if (missing(p)) messagena("p")
 g <- single(1)
-f.res <- .Fortran("ingama",
+f.res <- .Fortran("ingamaz",
 x=to.single(x),
 p=to.single(p),
 g=to.single(g))
