@@ -4,7 +4,7 @@ if (missing(n)) messagena("n")
 nn <- length(a)
 if (missing(a)) a <- single(nn)
 info <- integer(1)
-f.res <- .Fortran("mchl",
+f.res <- .Fortran("mchlz",
 a=to.single(a),
 n=to.integer(n),
 nn=to.integer(nn),
