@@ -1,7 +1,7 @@
 "precs" <-
 function() {
 prec <- single(1)
-f.res <- .Fortran("precs",
+f.res <- .Fortran("precsz",
 prec=to.single(prec))
 list(prec=f.res$prec)
 }
