@@ -3,7 +3,7 @@ function(ip,xlcnst=-1.0,s) {
 if (missing(ip)) messagena("ip")
 if (missing(s)) messagena("s")
 f <- single(1)
-f.res <- .Fortran("xerp",
+f.res <- .Fortran("xerpz",
 ip=to.integer(ip),
 xlcnst=to.single(xlcnst),
 s=to.single(s),
